@@ -8,7 +8,6 @@ use sqlx_core::postgres::{PgValue, PgValueRef, Postgres};
 use sqlx_core::row::Row;
 use sqlx_core::type_info::TypeInfo;
 use sqlx_core::types::chrono::{FixedOffset, NaiveTime};
-use sqlx_core::types::ipnetwork::IpNetwork;
 use sqlx_core::types::time::Time;
 use sqlx_core::types::{BigDecimal, Json, Uuid};
 use sqlx_core::value::ValueRef;
@@ -224,15 +223,6 @@ impl<'c> JsonCodec for PgValueRef<'c> {
                 }
                 return Ok(Bson::Null);
             }
-            "CIDR" | "INET" => {
-                let r: Option<IpNetwork> = Decode::<'_, Postgres>::decode(self)?;
-                return Ok(to_bson(&r).unwrap_or_default());
-            }
-            "CIDR[]" | "INET[]" => {
-                let r: Option<Vec<IpNetwork>> = Decode::<'_, Postgres>::decode(self)?;
-                return Ok(to_bson(&r).unwrap_or_default());
-            }
-
             "INTERVAL" => {
                 let r: Option<sqlx_core::postgres::types::PgInterval> =
                     Decode::<'_, Postgres>::decode(self)?;
@@ -251,6 +241,8 @@ impl<'c> JsonCodec for PgValueRef<'c> {
             }
             _ => {
                 //TODO
+                //"CIDR" | "INET"
+                //"CIDR[]" | "INET[]"
                 // "JSONPATH","JSONPATH[]",
                 // "INT8RANGE","INT8RANGE[]",
                 // "DATERANGE","DATERANGE[]",
